"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TrojanManager = void 0;
const grpc_js_1 = require("@grpc/grpc-js");
const grpc_transport_1 = require("@protobuf-ts/grpc-transport");
const api_1 = require("../protobuf/api");
const api_client_1 = require("../protobuf/api.client");
class TrojanManager {
    cl;
    transport;
    constructor({ host, port }) {
        this.transport = new grpc_transport_1.GrpcTransport({
            host: `${host}:${port}`,
            channelCredentials: grpc_js_1.ChannelCredentials.createInsecure(),
            'grpc.max_receive_message_length': 20 * 1024 * 1024,
            'grpc.max_send_message_length': 20 * 1024 * 1024,
        });
        this.cl = new api_client_1.TrojanServerServiceClient(this.transport);
    }
    async addAccount(passwordHashList) {
        const duplexCall = this.cl.setUsers();
        for await (const passwordHash of passwordHashList) {
            await duplexCall.requests.send({
                operation: api_1.SetUsersRequest_Operation.Add,
                status: {
                    ipLimit: 0,
                    ipCurrent: 0,
                    user: {
                        hash: passwordHash,
                        password: '',
                    },
                },
            });
        }
        await duplexCall.requests.complete();
        await duplexCall.status;
    }
    async removeAccount(passwordHashList) {
        const duplexCall = this.cl.setUsers();
        for await (const passwordHash of passwordHashList) {
            await duplexCall.requests.send({
                operation: api_1.SetUsersRequest_Operation.Delete,
                status: {
                    ipLimit: 0,
                    ipCurrent: 0,
                    user: {
                        hash: passwordHash,
                        password: '',
                    },
                },
            });
        }
        await duplexCall.requests.complete();
        await duplexCall.status;
    }
    async getFlows() {
        const streamingCall = this.cl.listUsers({});
        const accounts = [];
        for await (const user of streamingCall.responses) {
            const { status } = user;
            const passwordHash = status?.user?.hash;
            const upload = status?.trafficTotal?.uploadTraffic;
            const download = status?.trafficTotal?.downloadTraffic;
            if (!passwordHash)
                continue;
            const uploadInNumber = upload ? Number(upload) : 0;
            const downloadInNumber = download ? Number(download) : 0;
            accounts.push({
                passwordHash,
                flow: downloadInNumber + uploadInNumber,
            });
        }
        await streamingCall.status;
        return accounts;
    }
    async clearFlow(passwordHashList) {
        const setUserCall = this.cl.setUsers();
        for await (const passwordHash of passwordHashList) {
            await setUserCall.requests.send({
                operation: api_1.SetUsersRequest_Operation.Modify,
                status: {
                    ipLimit: 0,
                    ipCurrent: 0,
                    user: {
                        hash: passwordHash,
                        password: '',
                    },
                    trafficTotal: {
                        uploadTraffic: 0n,
                        downloadTraffic: 0n,
                    },
                },
            });
        }
        await setUserCall.requests.complete();
        await setUserCall.status;
    }
    disconnect() {
        this.transport.close();
    }
}
exports.TrojanManager = TrojanManager;
//# sourceMappingURL=trojan-manager.js.map