"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getConfig = exports.parseConfig = void 0;
const commander_1 = require("commander");
const yaml_1 = __importDefault(require("yaml"));
const fs_extra_1 = __importDefault(require("fs-extra"));
const path_1 = __importDefault(require("path"));
const parseConfig = () => {
    const options = commander_1.program.opts();
    commander_1.program
        .option('-l, --listen-address [addr:port]', 'listening address for this client', '0.0.0.0:4001')
        .requiredOption('-k, --key <password>', 'ssmgr client password')
        .option('--api <addr:port>', 'trojan-go API address')
        .option('--trojan-config <path>', 'trojan-go config file path')
        .option('--fake-website [addr:port]', 'run a fake website on address [addr:port], default to "127.0.0.1:4002" if not specified')
        .option('-d, --debug', 'verbose output for debugging (default: false)')
        .parse(process.argv);
    if (!options.api && !options.trojanConfig) {
        throw new Error('trojan-go API address or trojan-go config file path is required');
    }
    else if (options.api && options.trojanConfig) {
        throw new Error('trojan-go API address and trojan-go config file path are mutually exclusive');
    }
    if (!options.api && options.trojanConfig) {
        let trojanConfig;
        let isJSON = false;
        if (options.trojanConfig.endsWith('yaml')) {
            trojanConfig = yaml_1.default.parse(fs_extra_1.default.readFileSync(path_1.default.resolve(process.cwd(), options.trojanConfig), 'utf8'));
        }
        else {
            trojanConfig = fs_extra_1.default.readJSONSync(path_1.default.resolve(process.cwd(), options.trojanConfig));
            isJSON = true;
        }
        if (isJSON &&
            trojanConfig?.api?.['api_addr'] &&
            trojanConfig?.api?.['api_port']) {
            options.api = `${trojanConfig.api['api_addr']}:${trojanConfig.api['api_port']}`;
        }
        else if (!isJSON &&
            trojanConfig?.api?.['api-addr'] &&
            trojanConfig?.api?.['api-port']) {
            options.api = `${trojanConfig.api['api-addr']}:${trojanConfig.api['api-port']}`;
        }
        else {
            throw new Error('trojan-go config file must have the API feature enabled');
        }
    }
    if (options.fakeWebsite === true) {
        options.fakeWebsite = '127.0.0.1:4002';
    }
    return {
        debug: !!options.debug,
        addr: options.listenAddress?.split(':')[0] || '0.0.0.0',
        port: parseInt(options.listenAddress?.split(':')[1], 10) || 4001,
        key: options.key,
        apiHost: options.api?.split(':')[0] || 'localhost',
        apiPort: parseInt(options.api?.split(':')[1], 10),
        trojanConfig: options.trojanConfig,
        fakeWebsite: options.fakeWebsite,
    };
};
exports.parseConfig = parseConfig;
const getConfig = (() => {
    let config;
    return () => {
        if (!config) {
            config = parseConfig();
        }
        return config;
    };
})();
exports.getConfig = getConfig;
//# sourceMappingURL=config.js.map