"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.enableDebug = exports.trojanLogger = exports.logger = void 0;
const log4js_1 = require("log4js");
const path_1 = require("path");
const utils_1 = require("../utils");
const getLog4jsConfig = () => {
    const logPath = (0, path_1.join)(process.cwd(), 'logs');
    const log4jsConfig = utils_1.isProd
        ? {
            appenders: {
                out: { type: 'stdout' },
                app: {
                    type: 'dateFile',
                    keepFileExt: true,
                    filename: (0, path_1.join)(logPath, 'application.log'),
                    layout: { type: 'basic' },
                },
                trojan: {
                    type: 'dateFile',
                    keepFileExt: true,
                    filename: (0, path_1.join)(logPath, 'trojan.log'),
                    layout: { type: 'basic' },
                },
            },
            categories: {
                default: { appenders: ['app'], level: 'trace' },
                app: { appenders: ['app'], level: 'trace' },
                trojan: { appenders: ['trojan'], level: 'trace' },
            },
        }
        : {
            appenders: {
                out: { type: 'stdout', layout: { type: 'colored' } },
                app: {
                    type: 'dateFile',
                    keepFileExt: true,
                    filename: (0, path_1.join)(logPath, 'application.log'),
                    layout: { type: 'basic' },
                },
                trojan: {
                    type: 'dateFile',
                    keepFileExt: true,
                    filename: (0, path_1.join)(logPath, 'trojan.log'),
                    layout: { type: 'basic' },
                },
            },
            categories: {
                default: { appenders: ['out'], level: 'trace' },
                app: { appenders: ['app', 'out'], level: 'trace' },
                trojan: { appenders: ['trojan', 'out'], level: 'trace' },
            },
        };
    return log4jsConfig;
};
(0, log4js_1.configure)(getLog4jsConfig());
const logger = (0, log4js_1.getLogger)('app');
exports.logger = logger;
const trojanLogger = (0, log4js_1.getLogger)('trojan');
exports.trojanLogger = trojanLogger;
logger.level = utils_1.isProd ? process.env.LOG_LEVEL || 'warn' : 'trace';
trojanLogger.level = utils_1.isProd ? process.env.TROJAN_LOG_LEVEL || 'warn' : 'trace';
const enableDebug = () => {
    logger.level = 'debug';
    trojanLogger.level = 'debug';
};
exports.enableDebug = enableDebug;
//# sourceMappingURL=logger.js.map