"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.checkCode = exports.pack = void 0;
const crypto_1 = require("crypto");
const logger_1 = require("../logger");
const pack = (data) => {
    const message = JSON.stringify(data);
    const dataBuffer = Buffer.from(message);
    const length = dataBuffer.length;
    const lengthBuffer = Buffer.from(length.toString(16).padStart(8, '0'), 'hex');
    return Buffer.concat([lengthBuffer, dataBuffer]);
};
exports.pack = pack;
const checkCode = (key, data, code) => {
    const time = Number.parseInt(data.slice(0, 6).toString('hex'), 16);
    if (Math.abs(Date.now() - time) > 10 * 60 * 1000) {
        logger_1.logger.warn('Invalid message: Timed out.');
        return false;
    }
    const command = data.slice(6).toString();
    const hash = (0, crypto_1.createHash)('md5')
        .update(time + command + key)
        .digest('hex')
        .substr(0, 8);
    if (hash === code.toString('hex')) {
        return true;
    }
    else {
        logger_1.logger.warn('Invalid message: Hash mismatch. (Incorrect password)');
        return false;
    }
};
exports.checkCode = checkCode;
//# sourceMappingURL=utils.js.map