"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.startTrojan = void 0;
const execa_1 = __importDefault(require("execa"));
const os_1 = __importDefault(require("os"));
const path_1 = require("path");
const tcp_port_used_1 = __importDefault(require("tcp-port-used"));
const logger_1 = require("../logger");
const ensureTrojanPort = async (host, port) => {
    await tcp_port_used_1.default.waitUntilUsedOnHost(port, host, 1000, 10000);
};
const startTrojan = (trojanHost, trojanPort, configPath) => {
    const osPlatform = os_1.default.platform().toLowerCase();
    const osArch = os_1.default.arch().toLowerCase();
    if (!['x64', 'arm64'].includes(osArch)) {
        throw new Error(`Unsupported architecture: ${osArch}`);
    }
    if (!['linux', 'darwin'].includes(osPlatform)) {
        throw new Error(`Unsupported platform: ${osPlatform}`);
    }
    const bin = (0, path_1.join)(__dirname, '../../bin/trojan-go');
    const trojanProcess = (0, execa_1.default)(bin, ['--config', configPath], {
        all: true,
    });
    if (trojanProcess.all) {
        trojanProcess.all.on('data', (data) => {
            data
                .toString()
                .split(os_1.default.EOL)
                .forEach((log) => {
                if (log.length > 0) {
                    if (log.includes('[FATAL]') || log.includes('[ERROR]')) {
                        logger_1.trojanLogger.error(log.replace(/\[FATAL\]|\[ERROR\]/g, '').trim());
                    }
                    else if (log.includes('[WARN]')) {
                        logger_1.trojanLogger.warn(log.replace('[WARN]', '').trim());
                    }
                    else if (log.includes('[INFO]')) {
                        logger_1.trojanLogger.info(log.replace('[INFO]', '').trim());
                    }
                    else if (log.includes('[DEBUG]')) {
                        logger_1.trojanLogger.debug(log.replace('[DEBUG]', '').trim());
                    }
                    else {
                        logger_1.trojanLogger.debug(log.trim());
                    }
                }
            });
        });
    }
    ensureTrojanPort(trojanHost, trojanPort)
        .then(() => {
        trojanProcess.emit('api-service-ready', {});
    })
        .catch(() => {
        throw new Error('trojan-go API service is not ready after timeout.');
    });
    return trojanProcess;
};
exports.startTrojan = startTrojan;
//# sourceMappingURL=instance.js.map